"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useHtmlTableProps;

var _react = require("react");

var _TableLayout = _interopRequireDefault(require("./TableLayout"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function useTableLayout({
  tnode,
  settings
}) {
  return (0, _react.useMemo)(() => {
    return new _TableLayout.default(tnode, settings);
  }, [tnode, settings]);
}
/**
 * Customize the rendering logic of the table renderer via this hook.
 *
 * @param props - Props from custom renderer props.
 * @param options - Customize this hook behavior.
 *
 * @returns props for the {@link HTMLTable} component.
 *
 * @public
 */


function useHtmlTableProps({
  sharedProps,
  tnode,
  ...props
}, options = {}) {
  var _table$forceStretch;

  const {
    renderersProps: {
      table
    }
  } = sharedProps;
  const forceStretch = (_table$forceStretch = table === null || table === void 0 ? void 0 : table.forceStretch) !== null && _table$forceStretch !== void 0 ? _table$forceStretch : false;
  const contentWidth = typeof options.overrideContentWidth === 'number' ? options.overrideContentWidth : sharedProps.contentWidth;
  const settings = (0, _react.useMemo)(() => ({
    contentWidth,
    forceStretch
  }), [contentWidth, forceStretch]);
  const layout = useTableLayout({
    tnode,
    settings
  });
  return {
    layout,
    config: table || {},
    sharedProps,
    tnode,
    ...props
  };
}
//# sourceMappingURL=useHtmlTableProps.js.map